---
title: <span class="badge builder"></span> PieChartLegendOptions
---
# <span class="badge builder"></span> PieChartLegendOptions

## Constructor

```python
PieChartLegendOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> piechart.PieChartLegendOptions
```

### <span class="badge object-method"></span> as_table

```python
def as_table(as_table: bool) -> typing.Self
```

### <span class="badge object-method"></span> calcs

```python
def calcs(calcs: list[str]) -> typing.Self
```

### <span class="badge object-method"></span> display_mode

```python
def display_mode(display_mode: common.LegendDisplayMode) -> typing.Self
```

### <span class="badge object-method"></span> is_visible

```python
def is_visible(is_visible: bool) -> typing.Self
```

### <span class="badge object-method"></span> placement

```python
def placement(placement: common.LegendPlacement) -> typing.Self
```

### <span class="badge object-method"></span> show_legend

```python
def show_legend(show_legend: bool) -> typing.Self
```

### <span class="badge object-method"></span> sort_by

```python
def sort_by(sort_by: str) -> typing.Self
```

### <span class="badge object-method"></span> sort_desc

```python
def sort_desc(sort_desc: bool) -> typing.Self
```

### <span class="badge object-method"></span> values

```python
def values(values: list[piechart.PieChartLegendValues]) -> typing.Self
```

### <span class="badge object-method"></span> width

```python
def width(width: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [PieChartLegendOptions](./object-PieChartLegendOptions.md)
